Learn R Programming

subspaceMOA (version 0.6.0)

DSC_subclu: SubClu algorithm for use with DSC_ThreeStage

Description

An implementation of the SubClu algorithm that can be used with DSC_ThreeStage. For more details on this algorithm, consult SubClu

Usage

DSC_subclu(epsilon = 0.05, minSupport = 50, minOutputDim = 3)

Arguments

epsilon
this parameter determines the size of the epsilon environment for the DBSCAN that is run as a part of this algorithm.
minSupport
minimum number of points in the epsilon environment.
minOutputDim
minimum dimensionality that a cluster must have to be output. dsc <- DSC_ThreeStage(macro=DSC_subclu(),micro=DSC_subspaceCluStream()) dsd <- DSD_RandomRBFSubspaceGeneratorEvents() update(dsc,dsd,1000)