poissonThreshold
threshold value to determine wheter two bins will be
merged. Note that the value provided will be used as a negative power of 10.
E.g. if a value of 20 is provided here, then the algorithm will use a
threshold of 1.0*10^-20.
dsc <- DSC_ThreeStage(macro=DSC_p3c(),micro=DSC_subspaceCluStream())
dsd <- DSD_RandomRBFSubspaceGeneratorEvents()
update(dsc,dsd,1000)