this parameter determines the size of the epsilon environment for the DBSCAN that is run as a part of this algorithm.
minSupport
minimum number of points in the epsilon environment.
minOutputDim
minimum dimensionality that a cluster must have to be output.
dsc <- DSC_ThreeStage(macro=DSC_subclu(),micro=DSC_subspaceCluStream())
dsd <- DSD_RandomRBFSubspaceGeneratorEvents()
update(dsc,dsd,1000)